function varargout = dial_box(varargin)
% DIAL_BOX M-file for dial_box.fig
%      DIAL_BOX, by itself, creates a new DIAL_BOX or raises the existing
%      singleton*.
%
%      H = DIAL_BOX returns the handle to a new DIAL_BOX or the handle to
%      the existing singleton*.
%
%      DIAL_BOX('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DIAL_BOX.M with the given input arguments.
%
%      DIAL_BOX('Property','Value',...) creates a new DIAL_BOX or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before dial_box_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to dial_box_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help dial_box

% Last Modified by GUIDE v2.5 27-Apr-2005 10:50:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @dial_box_OpeningFcn, ...
                   'gui_OutputFcn',  @dial_box_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before dial_box is made visible.
function dial_box_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to dial_box (see VARARGIN)

% Choose default command line output for dial_box
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes dial_box wait for user response (see UIRESUME)
% uiwait(handles.figure1);

%text1=varargin{1};
%butt_text1=varargin{2};
%win_title=varargin{3};

data=varargin{1};
set(handles.text1,'string',data.text1);
set(handles.pushbutton1,'string',data.butt_text);
set(handles.output,'name',data.win_title);

leave=1;
while leave==0
end

% --- Outputs from this function are returned to the command line.
function varargout = dial_box_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

close(handles.output)
return
